@@ -31,6 +31,7 @@
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-icon-entry.h>
 
+#include "nothing.h"
 #include "panel-profile.h"
 #include "panel-gconf.h"
 #include "panel-util.h"
@@ -987,6 +988,10 @@ panel_properties_dialog_new (PanelToplevel *toplevel,
 	panel_widget_register_open_dialog (panel_toplevel_get_panel_widget (dialog->toplevel),
 					   dialog->properties_dialog);
 
+	g_signal_connect (dialog->properties_dialog, "event",
+			  G_CALLBACK (config_event),
+			  glade_xml_get_widget (gui, "notebook"));
+
 	gtk_widget_show (dialog->properties_dialog);
 
 	return dialog;
@@ -1014,11 +1019,15 @@ panel_properties_dialog_present (PanelToplevel *toplevel)
 			     "panel_properties_dialog",
 			     NULL);
 	if (gui == NULL) {
-		panel_error_dialog (gtk_window_get_screen (GTK_WINDOW (toplevel)),
+		char *secondary;
+		secondary = g_strdup_printf (_("Unable to load file '%s'."),
+					     GLADEDIR"/panel-properties-dialog.glade");
+		panel_error_dialog (NULL,
+				    gtk_window_get_screen (GTK_WINDOW (toplevel)),
 				    "cannot_display_properties_dialog", TRUE,
 				    _("Could not display properties dialog"),
-				    _("Unable to load file '%s'."),
-				    GLADEDIR "/panel-properties-dialog.glade");
+				    secondary);
+		g_free (secondary);
 		return;
 	}
 
